@@ -1,18 +1,24 @@
-from typing import Callable
+from typing import Callable, Type
 from scintillant.apimodels import SkillResponse
 from scintillant.apimodels.types import SkillRequestType, SkillResponseType
+from scintillant.outs import Dictionary
 
 
 class ContextUpdater:
     states = {}  # state_name: state_func
     exit_phrases = ['exit', 'выход', 'хватит', 'остановись']
 
-    def __init__(self, data: SkillRequestType):
+    def __init__(self, data: SkillRequestType, dictionary: Type[Dictionary] = None):
         # Default parameters for find state and complete it
         self.data = data
         self.context = data.context
         self.response = SkillResponse(status='ok')
 
+        if dictionary and data.user.client.type.lower() == 'voice':
+            self.dictionary = dictionary.voice()
+        elif dictionary:
+            self.dictionary = dictionary.text()
+
     @property
     def next_state(self):
         return self.context['state']
